@@ -298,11 +298,11 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Interface")))
 
-        box, category_vbox = gu.hig_category_vbox(_("User Interface"))
+        box, category_vbox = gu.hig_category_vbox(_("Interface"))
         page_vbox.pack_start(box, False)
 
         b = gu.nCheckButton('gui', 'web_browser_as_help_browser',
-            _("Use _web browser for online help"))
+            _("_Display the user manual in web browser"))
         category_vbox.pack_start(b, False)
         self.g_mainwin_user_resizeable = gu.nCheckButton('gui',
           'mainwin_user_resizeable', _("_Resizeable main window"))
@@ -481,7 +481,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         #############
         # midi setup
         #############
-        box, category_vbox = gu.hig_category_vbox(_("MIDI Setup"))
+        box, category_vbox = gu.hig_category_vbox(_("Sound Setup"))
         page_vbox.pack_start(box)
 
         self.g_fakesynth_radio = gu.RadioButton(None, _("_No sound"), None)
