@@ -20,6 +20,7 @@ import runtime
 import gtk
 import statistics, statisticsviewer
 import lessonfile
+import utils
 
 class Teacher(abstract.Teacher):
     #FIXME the following lines
@@ -84,24 +85,21 @@ class Teacher(abstract.Teacher):
     def play_question(self):
         if self.q_status == self.QSTATUS_NO:
             return
-        soundcard.play_note(self.get_int('config/preferred_instrument'), 4,
-             mpd.notename_to_int(self.m_question)+self.m_octave*12,
-             self.get_int('config/preferred_instrument_velocity'))
+        utils.play_note(4, 
+            mpd.notename_to_int(self.m_question) + self.m_octave * 12)
     def give_up(self):
         if not self.m_custom_mode:
             self.m_statistics.reset_session()
         self.q_status = self.QSTATUS_GIVE_UP
     def spank_me_play_question(self):
-        t1 = soundcard.PercussionTrack()
-        t1.note(8, 71, self.get_int('config/preferred_instrument_velocity'))
-        t2 = soundcard.Track()
+        t1 = utils.new_percussion_track()
+        t1.note(8, 71)
+        t2 = utils.new_track()
         t2.notelen_time(4)
-        t2.set_patch(self.get_int('config/preferred_instrument'))
-        t2.note(4, mpd.notename_to_int(self.m_question)+self.m_octave*12,
-                self.get_int('config/preferred_instrument_velocity'))
+        t2.note(4, mpd.notename_to_int(self.m_question)+self.m_octave*12)
         soundcard.synth.play_track(t1, t2)
     def spank_me(self):
-        soundcard.play_perc(4, 71, self.get_int('config/preferred_instrument_velocity'))
+        mpd.play_perc(4, 71)
 
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
